==> blanco.plugin.constants_0.6.0-src.zip: blancoConstantsPlugin/blanco/main/blanco/plugin/constants/wizards/AbstractBlancoConstantsWizardPage.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.plugin.constants.wizards;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.constants.BlancoConstantsPluginConstants;

/**
 */
public abstract class AbstractBlancoConstantsWizardPage extends WizardPage {
    /**
     */
    private Label labelMessage1;

    /**
     */
    private Label labelMessage2;

    /**
     */
    private ISelection selection;

    /**
     *
     * @param selection
     */
    public AbstractBlancoConstantsWizardPage(final ISelection selection) {
        super("wizardPage");
        setTitle("blancoConstants vOC pxEBU[h");
        this.selection = selection;
    }

    /**
     *
     * @param parent
     */
    public void createControl(final Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText("blancoConstants Wizardւ悤I");
        new Label(container, SWT.NONE).setText("̃EBU[hblancoConstantsvOCp\ɂȂ܂ł̎菇`܂B");
        new Label(container, SWT.NONE).setText("");
        new Label(container, SWT.NONE).setText("̃EBU[h̎傽ړÍAݒt@C(" + BlancoConstantsPluginConstants.TARGET_FILENAME + ")vWFNg̃[gtH_ɍ쐬邱ƂłB");
        new Label(container, SWT.NONE).setText("ݒt@C(" + BlancoConstantsPluginConstants.TARGET_FILENAME + ")Ɋւ󋵂͉L̂悤ɂȂĂ܂B");

        labelMessage1 = new Label(container, SWT.NONE);
        labelMessage1.setText("  1.vWFNg̃[gtH_ " + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@CVKɍ쐬܂B");
        labelMessage2 = new Label(container, SWT.NONE);
        labelMessage2.setText("  2.EBU[h(Finish)sƂɂVK" + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@C쐬ĕҏWsƂł܂B");

        setControl(container);

        IProject proj = BlancoConstantsWizard.getProject(selection);
        if (proj == null) {
            setErrorMessage("vWFNgIł");
            setPageComplete(false);
            labelMessage1.setText("  1.vWFNgIĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        if (proj.isOpen() == false) {
            setPageComplete(false);
            setErrorMessage("JĂvWFNgIĂAēxEBU[hsĂB");
            labelMessage1.setText("  1.IꂽvWFNg͊JĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        IFile file = proj.getFile(BlancoConstantsPluginConstants.TARGET_FILENAME);
        if (file.exists()) {
            labelMessage1.setText("  1.ɃvWFNg̃[g " + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@C݂Ă܂B");
            labelMessage2.setText("  2.EBU[h(Finish)sƂɂ" + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@C̕ҏWsƂł܂B");
        }
    }
}

==> blanco.plugin.constants_0.9.3-src.zip: blancoConstantsPlugin/blanco/main/blanco/plugin/constants/wizards/AbstractBlancoConstantsWizardPage.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.plugin.constants.wizards;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.constants.BlancoConstantsPluginConstants;

/**
 */
public abstract class AbstractBlancoConstantsWizardPage extends WizardPage {
    /**
     */
    private Label labelMessage1;

    /**
     */
    private Label labelMessage2;

    /**
     */
    protected ISelection selection;

    /**
     *
     * @param selection
     */
    public AbstractBlancoConstantsWizardPage(final ISelection selection) {
        super("wizardPage");
        setTitle("blancoConstants vOC pxEBU[h");
        this.selection = selection;
    }

    /**
     *
     * @param parent
     */
    public void createControl(final Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText("blancoConstants Wizardւ悤I");
        new Label(container, SWT.NONE).setText("̃EBU[hblancoConstantsvOCp\ɂȂ܂ł̎菇`܂B");
        new Label(container, SWT.NONE).setText("");
        new Label(container, SWT.NONE).setText("̃EBU[h̎傽ړÍAݒt@C(" + BlancoConstantsPluginConstants.TARGET_FILENAME + ")vWFNg̃[gtH_ɍ쐬邱ƂłB");
        new Label(container, SWT.NONE).setText("ݒt@C(" + BlancoConstantsPluginConstants.TARGET_FILENAME + ")Ɋւ󋵂͉L̂悤ɂȂĂ܂B");

        labelMessage1 = new Label(container, SWT.NONE);
        labelMessage1.setText("  1.vWFNg̃[gtH_ " + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@CVKɍ쐬܂B");
        labelMessage2 = new Label(container, SWT.NONE);
        labelMessage2.setText("  2.EBU[h(Finish)sƂɂVK" + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@C쐬ĕҏWsƂł܂B");

        setControl(container);

        IProject proj = BlancoConstantsWizard.getProject(selection);
        if (proj == null) {
            setErrorMessage("vWFNgIł");
            setPageComplete(false);
            labelMessage1.setText("  1.vWFNgIĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        if (proj.isOpen() == false) {
            setPageComplete(false);
            setErrorMessage("JĂvWFNgIĂAēxEBU[hsĂB");
            labelMessage1.setText("  1.IꂽvWFNg͊JĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        IFile file = proj.getFile(BlancoConstantsPluginConstants.TARGET_FILENAME);
        if (file.exists()) {
            labelMessage1.setText("  1.ɃvWFNg̃[g " + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@C݂Ă܂B");
            labelMessage2.setText("  2.EBU[h(Finish)sƂɂ" + BlancoConstantsPluginConstants.TARGET_FILENAME + "t@C̕ҏWsƂł܂B");
        }
    }
}
